@@ -1,3 +1,18 @@
+# -*- coding: utf-8 -*-
+# Copyright 2020 Paul Bailey
+#
+#    Licensed under the Apache License, Version 2.0 (the "License");
+#    you may not use this file except in compliance with the License.
+#    You may obtain a copy of the License at
+#
+#        https://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS,
+#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#    See the License for the specific language governing permissions and
+#    limitations under the License.
+
 from .base import MSTRBaseSession
 from .exceptions import (
     ExecutionCancelledException,
@@ -26,14 +41,16 @@ class MSTRRESTSession(
 ):
     pass
 
-    def execute_dataset_object(self, project_id, object_id):
+    def execute_dataset_object(self, project_id: str, object_id: str):
         response = self.post(
             "cubes/{}".format(object_id), headers={"X-MSTR-ProjectID": project_id}
         )
         if response.ok:
             return response.json()["instanceId"]
 
-    def get_dataset_instance_status(self, project_id, object_id, instance_id):
+    def get_dataset_instance_status(
+        self, project_id: str, object_id: str, instance_id: str
+    ):
         response = self.get(
             "datasets/{}/instances/{}/status".format(object_id, instance_id),
             headers={"X-MSTR-ProjectID": project_id},
